@@ -1,6 +1,6 @@
 <?php
 
-/*
+/**
  * @file
  *   Tests for field.drush.inc
  *
@@ -9,18 +9,28 @@
 class fieldCase extends Drush_CommandTestCase {
 
   public function testField() {
+    if (UNISH_DRUPAL_MAJOR_VERSION == 6) {
+      $this->markTestSkipped("Field API not available in Drupal 6.");
+    }
+
     $sites = $this->setUpDrupal(1, TRUE);
     $options = array(
       'yes' => NULL,
       'root' => $this->webroot(),
       'uri' => key($sites),
     );
+
+    $expected_url = '/admin/config/people/accounts/fields/subtitle';
+    if (UNISH_DRUPAL_MAJOR_VERSION >= 8) {
+      // Prepend for D8. We might want to change setUpDrupal() to add clean url.
+      $expected_url = '/index.php' . $expected_url;
+    }
     // Create two field instances on article content type.
     $this->drush('field-create', array('user', 'city,text,text_textfield', 'subtitle,text,text_textfield'), $options + array('entity_type' => 'user'));
     $output = $this->getOutput();
     list($city, $subtitle) = explode(' ', $output);
     $url = parse_url($subtitle);
-    $this->assertEquals('/admin/config/people/accounts/fields/subtitle', $url['path']);
+    $this->assertEquals($expected_url, $url['path']);
 
     // Assure that the second field instance was created correctly (subtitle).
     $this->verifyInstance('subtitle', $options);
@@ -29,7 +39,7 @@ class fieldCase extends Drush_CommandTestCase {
     $this->drush('field-update', array('subtitle'), $options);
     $output = $this->getOutput();
     $url = parse_url($this->getOutput());
-    $this->assertEquals('/admin/config/people/accounts/fields/subtitle', $url['path']);
+    $this->assertEquals($expected_url, $url['path']);
 
     // Assure that field-clone actually clones.
     $this->drush('field-clone', array('subtitle', 'subtitlecloned'), $options);
@@ -41,14 +51,13 @@ class fieldCase extends Drush_CommandTestCase {
   }
 
   function verifyInstance($name, $options, $expected = TRUE) {
-    $this->drush('field-info', array('fields'), $options + array('pipe' => NULL));
-    $output = $this->getOutputAsList();
+    $this->drush('field-info', array('fields'), $options + array('format' => 'json'));
+    $output = $this->getOutputFromJSON();
     $found = FALSE;
-    foreach($output as $row) {
-      $columns = explode(',', $row);
-      if ($columns[0] == $name) {
-        $this->assertEquals('text', $columns[1], $name . ' field is of type=text.');
-        $this->assertEquals('user', $columns[2], $name . ' field was added to user bundle.');
+    foreach($output as $key => $field) {
+      if ($key == $name) {
+        $this->assertEquals('text', $field->type, $name . ' field is of type=text.');
+        $this->assertEquals('user', current($field->bundle), $name . ' field was added to user bundle.');
         $found = TRUE;
         break;
       }
