@@ -58,6 +58,56 @@ class makeMakefileCase extends Drush_CommandTestCase {
     $this->runMakefileTest('no-patch-txt');
   }
 
+  /**
+   * Test no-core and working-copy in options array.
+   */
+  function testMakeOptionsArray() {
+    // Use the goptions-array.make file.
+    $config = $this->getMakefile('options-array');
+
+    $makefile_path = dirname(__FILE__) . '/makefiles';
+    $makefile = $makefile_path . '/' . $config['makefile'];
+    $install_directory = UNISH_SANDBOX . '/options-array';
+    $this->drush('make', array($makefile, $install_directory));
+
+    // Test cck_signup .git/HEAD file.
+    $this->assertFileExists($install_directory . '/sites/all/modules/cck_signup/.git/HEAD');
+    $contents = file_get_contents($install_directory . '/sites/all/modules/cck_signup/.git/HEAD');
+    $this->assertContains('2fe932c', $contents);
+
+    // Test context_admin .git/HEAD file.
+    $this->assertFileExists($install_directory . '/sites/all/modules/context_admin/.git/HEAD');
+    $contents = file_get_contents($install_directory . '/sites/all/modules/context_admin/.git/HEAD');
+    $this->assertContains('eb9f05e', $contents);
+  }
+
+  /**
+   * Test per project working-copy option.
+   */
+  function testMakeOptionsProject() {
+    // Use the options-project.make file.
+    $config = $this->getMakefile('options-project');
+
+    $makefile_path = dirname(__FILE__) . '/makefiles';
+    $options = array('no-core' => NULL);
+    $makefile = $makefile_path . '/' . $config['makefile'];
+    $install_directory = UNISH_SANDBOX . '/options-project';
+    $this->drush('make', array($makefile, $install_directory), $options);
+
+    // Test context_admin .git/HEAD file.
+    $this->assertFileExists($install_directory . '/sites/all/modules/context_admin/.git/HEAD');
+    $contents = file_get_contents($install_directory . '/sites/all/modules/context_admin/.git/HEAD');
+    $this->assertContains('eb9f05e', $contents);
+
+    // Test cck_signup .git/HEAD file does not exist.
+    $this->assertFileNotExists($install_directory . '/sites/all/modules/cck_signup/.git/HEAD');
+
+    // Test caption_filter .git/HEAD file.
+    $this->assertFileExists($install_directory . '/sites/all/modules/contrib/caption_filter/.git/HEAD');
+    $contents = file_get_contents($install_directory . '/sites/all/modules/contrib//caption_filter/.git/HEAD');
+    $this->assertContains('c9794cf', $contents);
+  }
+
   function testMakePatch() {
     $this->runMakefileTest('patch');
   }
@@ -66,10 +116,31 @@ class makeMakefileCase extends Drush_CommandTestCase {
     $this->runMakefileTest('include');
   }
 
+  /**
+   * Test git support on includes directive.
+   */
+  function testMakeIncludesGit() {
+    $config = $this->getMakefile('includes-git');
+    $options = array();
+    $makefile = $this->makefile_path . DIRECTORY_SEPARATOR . $config['makefile'];
+    $this->drush('make', array($makefile, UNISH_SANDBOX . '/test-build'), $options);
+    
+    // Verify that core and example main module were downloaded.
+    $this->assertFileExists(UNISH_SANDBOX . '/test-build/README.txt');
+    $this->assertFileExists(UNISH_SANDBOX . '/test-build/sites/all/modules/contrib/apachesolr/README.txt');
+    
+    // Verify that module included in sub platform was downloaded.
+    $this->assertFileExists(UNISH_SANDBOX . '/test-build/sites/all/modules/contrib/jquery_update/README.txt');
+  }
+
   function testMakeRecursion() {
     $this->runMakefileTest('recursion');
   }
 
+  function testMakeRecursionOverride() {
+    $this->runMakefileTest('recursion-override');
+  }
+
   function testMakeSvn() {
     // Silently skip svn test if svn is not installed.
     exec('which svn', $output, $whichSvnErrorCode);
@@ -383,14 +454,14 @@ class makeMakefileCase extends Drush_CommandTestCase {
         'name'     => 'Test --no-patch-txt option',
         'makefile' => 'patches.make',
         'build'    => TRUE,
-        'md5' => 'e43b25505a5edfcdf25b4eaa064978b2',
+        'md5' => '59267a04f98374ed5b0b75e90cefcd9c',
         'options'  => array('no-core' => NULL, 'no-patch-txt' => NULL),
       ),
       'patch' => array(
         'name'     => 'Test patching and writing of PATCHES.txt file',
         'makefile' => 'patches.make',
         'build'    => TRUE,
-        'md5' => '56f1613fc8b6a9f03ab62cfa0300df4c',
+        'md5' => 'edf94818907bff754b24ac5c34506028',
         'options'  => array('no-core' => NULL),
       ),
       'include' => array(
@@ -400,6 +471,12 @@ class makeMakefileCase extends Drush_CommandTestCase {
         'md5' => 'e2e230ec5eccaf5618050559ab11510d',
         'options'  => array(),
       ),
+      'includes-git' => array(
+        'name'     => 'Including makefiles from remote repositories',
+        'makefile' => 'includes-main.make',
+        'build'    => TRUE,
+        'options'  => array(),
+      ),      
       'recursion' => array(
         'name'     => 'Recursion',
         'makefile' => 'recursion.make',
@@ -410,6 +487,15 @@ class makeMakefileCase extends Drush_CommandTestCase {
           'contrib-destination' => 'profiles/drupal_forum',
         ),
       ),
+      'recursion-override' => array(
+        'name' => 'Recursion overrides',
+        'makefile' => 'recursion-override.make',
+        'build' => TRUE,
+        'md5' => 'a13c3d5d416be9fa78569514844b96a2',
+        'options' => array(
+          'no-core' => NULL,
+        ),
+      ),
       'svn' => array(
         'name'     => 'SVN',
         'makefile' => 'svn.make',
@@ -444,7 +530,7 @@ class makeMakefileCase extends Drush_CommandTestCase {
         'name'     => 'Contrib-destination attribute',
         'makefile' => 'contrib-destination.make',
         'build'    => TRUE,
-        'md5' => 'd615d004adfa8ebfe44e91119b88389c',
+        'md5' => '2aed36201ede1849ce43d9b7d6f7e9e1',
         'options'  => array('no-core' => NULL, 'contrib-destination' => '.'),
       ),
       'file' => array(
@@ -515,7 +601,7 @@ class makeMakefileCase extends Drush_CommandTestCase {
         'name'     => 'Extract archives',
         'makefile' => 'file-extract.make',
         'build'    => TRUE,
-        'md5' => 'f92471fb7979e45d2554c61314ac6236',
+        'md5' => 'b43d271ab3510eb33c1e300c78893458',
         // @todo This test often fails with concurrency set to more than one.
         'options'  => array('no-core' => NULL, 'concurrency' => 1),
       ),
@@ -554,6 +640,18 @@ class makeMakefileCase extends Drush_CommandTestCase {
         'md5' => '643a603025a20d498eb583a1e7970bad',
         'options'  => array(),
       ),
+      'options-array' => array(
+        'name'     => 'Test global options array',
+        'makefile' => 'options-array.make',
+        'build'    => TRUE,
+        'options'  => array(),
+      ),
+      'options-project' => array(
+        'name'     => 'Test per-project options array',
+        'makefile' => 'options-project.make',
+        'build'    => TRUE,
+        'options'  => array(),
+      ),
     );
     return $tests[$key];
   }
