@@ -13,25 +13,44 @@ class EnDisUnListCase extends Drush_CommandTestCase {
 
   public function testEnDisUnList() {
     $sites = $this->setUpDrupal(1, TRUE);
-    $options = array(
+    $options_no_pipe = array(
       'yes' => NULL,
-      'pipe' => NULL,
       'root' => $this->webroot(),
       'uri' => key($sites),
       'cache' => NULL,
       'skip' => NULL, // No FirePHP
-      'invoke' => NULL, // Don't validate options
+      'strict' => 0, // Don't validate options
+    );
+    $options = $options_no_pipe + array(
+      'pipe' => NULL,
     );
     $this->drush('pm-download', array('devel'), $options);
     $this->drush('pm-list', array(), $options + array('no-core' => NULL, 'status' => 'not installed'));
     $list = $this->getOutputAsList();
     $this->assertTrue(in_array('devel', $list));
 
-    $this->drush('pm-enable', array('devel'), $options);
+    $this->drush('pm-enable', array('devel'), $options_no_pipe);
+    $output = $this->getOutput();
+    $this->assertContains('access devel information', $output);
+    $this->drush('pm-info', array('devel'), $options);
+    $output = $this->getOutputFromJSON('devel');
+    $expected = array(
+      'extension' => 'devel',
+      'project' => 'devel',
+      'type' => 'module',
+      'title' => 'Devel',
+      'status' => 'enabled',
+    );
+    foreach ($expected as $key => $value) {
+      $this->assertEquals($expected[$key], $value);
+    }
+
     $this->drush('pm-list', array(), $options + array('status' => 'enabled'));
     $list = $this->getOutputAsList();
     $this->assertTrue(in_array('devel', $list));
-    $this->assertTrue(in_array('bartik', $list), 'Themes are in the pm-list');
+    // In D7, the testing profile uses 'bartik', whereas in D8, 'stark' is used.
+    $themeToCheck = UNISH_DRUPAL_MAJOR_VERSION >= 8 ? 'stark' : (UNISH_DRUPAL_MAJOR_VERSION == 7 ? 'bartik' : 'garland');
+    $this->assertTrue(in_array($themeToCheck, $list), 'Themes are in the pm-list');
 
     $this->drush('sql-query', array("SELECT path FROM menu_router WHERE path = 'devel/settings';"), array('root' => $this->webroot(), 'uri' => key($sites)));
     $list = $this->getOutputAsList();
@@ -59,6 +78,9 @@ class EnDisUnListCase extends Drush_CommandTestCase {
     $this->assertEmpty($output, 'Devel variable was uninstalled.');
 
     // Test pm-enable is able to download dependencies.
+    if (UNISH_DRUPAL_MAJOR_VERSION >= 8) {
+      $this->markTestSkipped("pathauto does not have a release for Drupal 8 yet.");
+    }
     $this->drush('pm-download', array('pathauto'), $options);
     $this->drush('pm-enable', array('pathauto'), $options + array('resolve-dependencies' => TRUE));
     $this->drush('pm-list', array(), $options + array('status' => 'enabled'));
