@@ -1,6 +1,6 @@
 <?php
 
-/*
+/**
 * @file
 *  For now we only test sql-sync in simulated mode.
 *
@@ -8,13 +8,14 @@
 *  overwriting one site with another.
 */
 
-/*
+/**
  *  @group slow
  *  @group commands
+ *  @group sql
  */
 class sqlSyncTest extends Drush_CommandTestCase {
 
-  /*
+  /**
    * Covers the following responsibilities.
    *   - A user created on the source site is copied to the destination site.
    *   - The email address of the copied user is sanitized on the destination site.
@@ -22,7 +23,7 @@ class sqlSyncTest extends Drush_CommandTestCase {
    * General handling of site aliases will be in sitealiasTest.php.
    */
   public function testLocalSqlSync() {
-    if (strpos(UNISH_DB_URL, 'sqlite') !== FALSE) {
+    if ($this->db_driver() == 'sqlite') {
       $this->markTestSkipped('SQL Sync does not apply to SQLite.');
       return;
     }
@@ -60,11 +61,13 @@ class sqlSyncTest extends Drush_CommandTestCase {
     );
     $this->drush('user-create', array($name), $options + array('password' => 'password', 'mail' => $mail));
 
-    // Copy stage to dev with --sanitize
+    // Copy stage to dev with --sanitize.
     $sync_options = array(
       'sanitize' => NULL,
       'yes' => NULL,
-      'dump-dir' => $dump_dir
+      'dump-dir' => $dump_dir,
+      // @todo test wildcards expansion from within sql-sync.
+      // 'skip-tables-list' => 'role_permiss*',
     );
     $this->drush('sql-sync', array('@stage', '@dev'), $sync_options);
 
@@ -86,15 +89,18 @@ class sqlSyncTest extends Drush_CommandTestCase {
     $output = $this->getOutput();
     $row  = str_getcsv($output);
     $uid = $row[1];
-    $this->assertEquals("user+$uid@localhost", $row[2], 'email address was sanitized on destination site.');
+    $this->assertEquals("user+$uid@localhost.localdomain", $row[2], 'email address was sanitized on destination site.');
     $this->assertEquals($name, $row[0]);
 
+    // @todo Confirm that the role_permissions table no longer exists in dev site (i.e. wildcard expansion works in sql-sync).
+    // $this->drush('sql-query', array('SELECT * FROM role_permission'), $options, NULL, NULL, self::EXIT_ERROR);
+
     // Copy stage to dev with --sanitize and a fixed sanitized email
     $sync_options = array(
       'sanitize' => NULL,
       'yes' => NULL,
       'dump-dir' => $dump_dir,
-      'sanitize-email' => 'user@localhost',
+      'sanitize-email' => 'user@mysite.org',
     );
     $this->drush('sql-sync', array('@stage', '@dev'), $sync_options);
 
@@ -108,7 +114,7 @@ class sqlSyncTest extends Drush_CommandTestCase {
     $output = $this->getOutput();
     $row  = str_getcsv($output);
     $uid = $row[1];
-    $this->assertEquals("user@localhost", $row[2], 'email address was sanitized (fixed email) on destination site.');
+    $this->assertEquals("user@mysite.org", $row[2], 'email address was sanitized (fixed email) on destination site.');
     $this->assertEquals($name, $row[0]);
   }
 }
